@@ -20,7 +20,7 @@ class Dispatcher:
         logging.info("dispatcher {} started".format(self.__name))
 
     def stop(self):
-        if self.__running:
+        if self._running:
             self._queue.put(self._done)
             # Wait for actual termination
             self._thread.join()
@@ -67,7 +67,7 @@ class Dispatcher:
             key = type(event)
             handlers = self._mapping.get(key)
             if handlers is None:
-                raise RuntimeError("[dispatcher {}] failed to find handler for event type {0}".format(
+                raise RuntimeError("[dispatcher {}] failed to find handler for event type {}".format(
                     self.__name, type(event)))
             for handler in handlers:
                 try:
